---
title: DjongoNxt Aggregation
permalink: /djongonxt-aggregation/
layout: djongoNxt

---

## Using Aggregation Operators


<!--
## Django Admin MongoDB dashboard

<A pic?>

Djongo dashboard is a web interface integrated with Django Admin for controlling and monitoring the status of the MongoDB server

<What types can I monitor>
Raw SQL support
C binaries for improved performance
Issue analysis and resolution
Change stream cursor 

-->